# Personal utilities for Conrad F Storz IV (CFSIV)

useage:

import cfsiv_utils.filehandling as fh
import cfsiv_utils.time_strings as ts
import cfsiv_utils.WebScraping as ws


This repository is uploaded to PyPi as "CFSIV-utils"
